use std::path::Path;

pub fn call(template_name: &str) -> String {
    let user_file_path = format!("templates/{}", template_name);
    if Path::new(&user_file_path).exists() {
        user_file_path
    } else {
        format!("default_templates/{}", template_name)
    }
}
